@@ -19,6 +19,9 @@ from typing import Dict
 import pandas as pd
 
 
+InputDict = Dict[str, Dict[str, str]]
+
+
 def _compose_entry(measurement: str, timestamp: pd.Timestamp):
     """
     Compose new Time Series entry.
@@ -32,19 +35,13 @@ def _compose_entry(measurement: str, timestamp: pd.Timestamp):
 
 
 def process(
-    measurement: str, data_source: Dict[str, any], date_from: datetime, date_to: datetime
+    measurement: str,
+    data_source: Dict[str, any],
+    time_series: InputDict,
+    tags: InputDict,
+    date_from: datetime,
+    date_to: datetime,
 ) -> pd.DataFrame:
-    """
-    Fake processor for generating random values for the
-    "Electricity Price" measurement in the given date window.
-
-    :param str measurement: Measurement to generate Time Series for.
-    :param Dict[str, any] data_source: Data source to generate Time Series for.
-    :param datetime date_from: Start generation from.
-    :param datetime date_to: End generation on.
-    :return: Generated DataFrame.
-    """
-
     # Simulate calculation delay.
     time.sleep(3)
 
